///// CapacitorView.java /////
/**
 * Class that implements the Capacitor view.
 * @author Jesus Márquez Barrera
 */

import java.awt.*;
import java.awt.geom.*;

import java.io.*;

public class CapacitorView implements Serializable{

  private static final double xPoints[]={0      , 22.0/51, 22.0/51, 22.0/51, 28.0/51, 28.0/51, 28.0/51, 1};
  private static final double yPoints[]={26.0/51, 26.0/51, 40.0/51, 12.0/51, 12.0/51, 40.0/51, 26.0/51, 26.0/51};
  private static final Path2D.Double polyline_h= new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
  private static final Path2D.Double polyline_v= new Path2D.Double(Path2D.WIND_EVEN_ODD,xPoints.length);
  private Capacitor c;
  
  static {  // static initialization block. It creates a spring of length = 1.
    // Horizontal Capacitor View
    for (int index = 0; index < xPoints.length; index++){
      if(index%2==0)
        polyline_h.moveTo(xPoints[index], yPoints[index]);
      else
        polyline_h.lineTo(xPoints[index], yPoints[index]);
    }

    // Vertical Capacitor View
    for (int index = 0; index < xPoints.length; index++){
      if(index%2==0)
        polyline_v.moveTo(yPoints[index], xPoints[index]);
      else
        polyline_v.lineTo(yPoints[index], xPoints[index]);
    }
  }

  public CapacitorView(Capacitor _c){
  	c=_c;
  }

  public void draw(Graphics2D g){
  	int tlx = c.topLeftX();
  	int tly = c.topLeftY();
  	int w = c.width();
  	AffineTransform at = AffineTransform.getTranslateInstance(tlx,tly);
  	at.scale(w,w);
    Path2D.Double shape=new Path2D.Double();
    if(c.getDirection()==0){
      shape = (Path2D.Double) at.createTransformedShape(polyline_h);
      c.setDirection(1);
    }
    else{
      shape = (Path2D.Double) at.createTransformedShape(polyline_v);
      c.setDirection(0);
    }
    if(c.getSelected())
  		if (c.getOverWrite())
  			g.setColor(Color.RED);
  		else g.setColor(Color.BLUE);
  	else
    	g.setColor(Color.BLACK);
    g.draw(shape);

  }
}