///// CircuitDrawer.java /////
/**
 * Main Class of the Drawer. Set the GUI.
 * @author Jesus Márquez Barrera. 
 */

import javax.swing.*;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;

import java.awt.*;
import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.event.*;

public class CircuitDrawer {
	public static void main(String[] args) {
		CircuitDrawer_GUI drawer_gui = new CircuitDrawer_GUI();
		drawer_gui.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		drawer_gui.setVisible(true);
	}
}

class CircuitDrawer_GUI extends JFrame{

	public CircuitDrawer_GUI(){
		setTitle("My First Circuit Drawer");
		setExtendedState(JFrame.MAXIMIZED_BOTH);
		//add(m.getView());
		//FileMenuListener flistener = new FileMenuListener(m);
		//EditMenuListener elistener = new EditMenuListener(m);
		//CircuitMenuListener clistener = new CircuitMenuListener(m);
		setJMenuBar(createDrawerMenuBar(/*flistener,elistener,clistener*/));
		addComponentsToPane(getContentPane());
	}

	private Container addComponentsToPane(Container pane){
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		int panewidth = screenSize.width - 100;
		int paneheight = screenSize.height - 110;
		int topLeftX = 0;
		int topLeftY = 10;
		JPanel drawerButtonMenu = buttonMenu();
		pane.setLayout(new BorderLayout(10,0));
		pane.add(drawerButtonMenu,BorderLayout.LINE_START);
		Matrix matrix = new Matrix(panewidth,paneheight,topLeftX,topLeftY,4,false);//dimensions of panel, vertical cells shown.
		for(int i=0;i<matrix.getYCellShown();i++){
			for(int j=0;j<matrix.getXCellShown();j+=2){
				MatrixElement me = new MatrixElement();
				if((i+j)%2==0)
					me.setMyElement(new Resistor(matrix.getTopLeftX()+j*matrix.getCellShownSize(),matrix.getTopLeftY()+i*matrix.getCellShownSize(),matrix.getCellShownSize()));
				//else if ((i+j)%3==0)
				//	me.setMyElement(new Inductor(matrix.getTopLeftX()+j*matrix.getCellShownSize(),matrix.getTopLeftY()+i*matrix.getCellShownSize(),matrix.getCellShownSize()));
				//else if ((i+j)%2==0)
				//	me.setMyElement(new Capacitor(matrix.getTopLeftX()+j*matrix.getCellShownSize(),matrix.getTopLeftY()+i*matrix.getCellShownSize(),matrix.getCellShownSize()));
				//else
					me.setMyElement(new Wire(matrix.getTopLeftX()+j*matrix.getCellShownSize(),matrix.getTopLeftY()+i*matrix.getCellShownSize(),matrix.getCellShownSize()));

				matrix.addElement(me,j,i);
			}
		}
		matrix.resizeShownMatrix(16);
		matrix.resizeShownMatrix(6);
		pane.add(matrix.getView(),BorderLayout.CENTER);
		return pane;
	}

	private JPanel buttonMenu(){
		JPanel buttonMenu = new JPanel();
		buttonMenu.setLayout(new BoxLayout(buttonMenu,BoxLayout.Y_AXIS));
		addAButton("ButtonIcons/wire1.png",buttonMenu);
		addAButton("ButtonIcons/resistor.png",buttonMenu);
		addAButton("ButtonIcons/capacitor.png",buttonMenu);
		addAButton("ButtonIcons/inductor.png",buttonMenu);
		addAButton("ButtonIcons/VoltageSource.png",buttonMenu);
		addAButton("ButtonIcons/GridOn.png",buttonMenu);
		addAButton("ButtonIcons/Remove.png",buttonMenu);
		addAButton("ButtonIcons/Rotate.png",buttonMenu);
		return buttonMenu;
	}

	private static void addAButton(String icon, JPanel c){
		JButton button = new JButton(new ImageIcon(icon));
		c.add(button);
	}

	private JMenuBar createDrawerMenuBar(){ 
		
		// args FileMenuListener fl, EditMenuListener el, CircuitMenuListener cl
		JMenuBar mb = new JMenuBar();

		JMenu menu = new JMenu("File");
		mb.add(menu);

		JMenuItem menuItem = new JMenuItem("Save");
		//menuItem.addActionListener(fl);
		menu.add(menuItem);
        menuItem.setEnabled(false);

		menuItem = new JMenuItem("Load");
      	//menuItem.addActionListener(fl);
      	menu.add(menuItem);
        menuItem.setEnabled(false);

        menu = new JMenu ("Edit");
      	mb.add(menu);

      	menuItem = new JMenuItem("Zoom +");
      	//menuItem.addActionListener(el);
      	menu.add(menuItem);
        menuItem.setEnabled(false);

      	menuItem = new JMenuItem("Zoom -");
      	//menuItem.addActionListener(el);
      	menu.add(menuItem);
        menuItem.setEnabled(false);

		menu = new JMenu ("Circuit");
      	mb.add(menu);      	

      	menuItem = new JMenuItem("Check Closed");
      	//menuItem.addActionListener(cl);
      	menu.add(menuItem);
        menuItem.setEnabled(false);

        JMenu subMenu = new JMenu("Simulate");  
      	menu.add(subMenu);      	
        subMenu.setEnabled(false);

        return mb;
	}
}