///// Matrix.java /////
/**
 * Matrix itself. Array of circuit elements. Arrange the position of the components.
 * @author Jesus Márquez Barrera
 */

import java.awt.*;
import java.awt.event.*;
import java.awt.geom.Point2D.*;
import java.io.*;

public class Matrix implements ActionListener{

	private int panewidth, paneheight, topLeftX, topLeftY, diferenceX, diferenceY, xCell, cellSize, xCellShown, yCellShown, cellShownSize;
	private boolean grid_on;
	private static final int YCELL=22; // Numero de Celdas matriz completa
	private MatrixElement [][] matrix, shownMatrix; // matriz completa, matriz mostrada
	private MatrixGrid grid;
	private MatrixView view; // vista de la matriz

	public Matrix(int w, int h, int tlx, int tly, int y, boolean sg){
		panewidth = w;
		paneheight = h;
		topLeftX = tlx;
		topLeftY =tly;
		yCellShown=y;
		grid_on=sg;

		//System.out.println(panewidth);
		//System.out.println(paneheight);
		//System.out.println(topLeftX);
		//System.out.println(topLeftY);
		//System.out.println(yCellShown);
		//System.out.println(grid_on);

		cellSize=paneheight/YCELL;
		xCell=panewidth/cellSize;
		matrix = new MatrixElement[YCELL][xCell];

		//System.out.println(cellSize);
		//System.out.println(xCell);
		//System.out.println(diference);

		for(int i=0;i<YCELL;i++){
			for(int j=0;j<xCell;j++){
				matrix[i][j]=new MatrixElement();
			}
		}

		cellShownSize=paneheight/yCellShown;
		xCellShown=panewidth/cellShownSize;
		shownMatrix = new MatrixElement[yCellShown][xCellShown];

		//System.out.println(cellShownSize);
		//System.out.println(xCellShown);

		diferenceX=(xCell-xCellShown)/2;
		diferenceY=(YCELL-yCellShown)/2;

		for(int i=0;i<yCellShown;i++){
			for(int j=0;j<xCellShown;j++){
				shownMatrix[i][j]=matrix[diferenceY+i][diferenceX+j];
			}
		}

		grid = new MatrixGrid(this);
		view = new MatrixView(this);
	}

	public boolean isGridOn(){
		return grid_on;
	}

	public int getXCell(){
		return xCell;
	}

	public int getYCell(){
		return YCELL;
	}

	public int getXCellShown(){
		return xCellShown;
	}

	public int getYCellShown(){
		return yCellShown;
	}

	public int getCellShownSize(){
		return cellShownSize;
	}

	public MatrixElement [][] getMatrix(){
		return matrix;
	}

	public MatrixElement [][] getShownMatrix(){
		return shownMatrix;
	}

	public MatrixGrid getGrid(){
		return grid;
	}

	public int getTopLeftX(){
		return topLeftX;
	}

	public int getTopLeftY(){
		return topLeftY;
	}


	public MatrixView getView(){
		return view;
	}

	public void actionPerformed (ActionEvent event) {  // repaint
		view.repaint();
    }

	public void addElement(MatrixElement m, int x, int y){ //falta evitar sobreescritura de celdas
		matrix[diferenceY+y][diferenceX+x]=m;
		shownMatrix[y][x]=m;
		//m.getMyElement().resize(x*cellShownSize, y*cellShownSize, cellShownSize);
		view.repaint();
	}
	
	public void resizeShownMatrix(int y){
		yCellShown=y; 
		cellShownSize=paneheight/yCellShown;
		xCellShown=panewidth/cellShownSize;
		diferenceX=(xCell-xCellShown)/2;
		diferenceY=(YCELL-yCellShown)/2;
		shownMatrix = new MatrixElement[yCellShown][xCellShown];
		for(int i=0;i<yCellShown;i++){
			for(int j=0;j<xCellShown;j++){
				shownMatrix[i][j]=matrix[diferenceY+i][diferenceX+j];
				shownMatrix[i][j].resizeMyElement(j,i,topLeftX,topLeftY,cellShownSize);
			}
		}
		grid= new MatrixGrid(this);
		view.repaint();
	}

	public void setMatrix(MatrixElement[][] m){
		matrix=m;
		resizeShownMatrix(12);
	}

	public void setGridOn(boolean set){
		grid_on=set;
		view.repaint();
	}

	public Point getShownMatrixIndex(Point p){
		int x_ = (int) (p.getX())/this.cellShownSize;
		int y_ = (int) (p.getY())/this.cellShownSize;
		if(x_ < 0) x_ = 0;
		if(y_ < 0) y_ = 0;
		return new Point(x_,y_);
	}
}
