///// VoltageSourceView.java /////
/**
 * Class that implements the Voltage Source view.
 * @author Jesus Márquez Barrera
 */

import java.awt.*;
import java.lang.*;
import java.awt.geom.*;

import java.io.*;

public class VoltageSourceView implements Serializable{

  private static final Path2D.Double polyline_u = new Path2D.Double();
  private static final Path2D.Double polyline_d = new Path2D.Double();
  private static final Path2D.Double polyline_l = new Path2D.Double();
  private static final Path2D.Double polyline_r = new Path2D.Double();
  private VoltageSource vs;
  
  static {  // static initialization block. It creates a spring of length = 1.
  	// Up Voltage Source view
   	polyline_u.moveTo(26.0/51,0.0);
    polyline_u.lineTo(26.0/51,14.0/51);    
    polyline_u.append(new Ellipse2D.Double(14.0/51, 14.0/51, 25.0/51, 25.0/51),false);

    polyline_u.moveTo(26.0/51,16.0/51);
    polyline_u.lineTo(26.0/51,20.0/51);
    polyline_u.moveTo(24.0/51,18.0/51);
    polyline_u.lineTo(28.0/51,18.0/51);

    polyline_u.moveTo(24.0/51,34.0/51);
    polyline_u.lineTo(28.0/51,34.0/51);

    polyline_u.moveTo(26.0/51,39.0/51);
    polyline_u.lineTo(26.0/51,1.0);

    // Left Voltage Source view
   	polyline_l.moveTo(0.0,26.0/51);
    polyline_l.lineTo(14.0/51,26.0/51);    
    polyline_l.append(new Ellipse2D.Double(14.0/51, 14.0/51, 25.0/51, 25.0/51),false);

    polyline_l.moveTo(16.0/51,26.0/51);
    polyline_l.lineTo(20.0/51,26.0/51);
    polyline_l.moveTo(18.0/51,24.0/51);
    polyline_l.lineTo(18.0/51,28.0/51);

    polyline_l.moveTo(34.0/51,24.0/51);
    polyline_l.lineTo(34.0/51,28.0/51);

    polyline_l.moveTo(39.0/51,26.0/51);
    polyline_l.lineTo(1.0,26.0/51);

	// Down Voltage Source view
   	polyline_d.moveTo(26.0/51,1.0);
    polyline_d.lineTo(26.0/51,39.0/51);    
    polyline_d.append(new Ellipse2D.Double(14.0/51, 14.0/51, 25.0/51, 25.0/51),false);

    polyline_d.moveTo(26.0/51,36.0/51);
    polyline_d.lineTo(26.0/51,32.0/51);
    polyline_d.moveTo(24.0/51,34.0/51);
    polyline_d.lineTo(28.0/51,34.0/51);

    polyline_d.moveTo(24.0/51,18.0/51);
    polyline_d.lineTo(28.0/51,18.0/51);

    polyline_d.moveTo(26.0/51,14.0/51);
    polyline_d.lineTo(26.0/51,0.0);

    // Right Voltage Source view
   	polyline_r.moveTo(1.0,26.0/51);
    polyline_r.lineTo(39.0/51,26.0/51);    
    polyline_r.append(new Ellipse2D.Double(14.0/51, 14.0/51, 25.0/51, 25.0/51),false);

    polyline_r.moveTo(36.0/51,26.0/51);
    polyline_r.lineTo(32.0/51,26.0/51);
    polyline_r.moveTo(34.0/51,24.0/51);
    polyline_r.lineTo(34.0/51,28.0/51);

    polyline_r.moveTo(18.0/51,24.0/51);
    polyline_r.lineTo(18.0/51,28.0/51);

    polyline_r.moveTo(14.0/51,26.0/51);
    polyline_r.lineTo(0.0,26.0/51);
  }

  public VoltageSourceView(VoltageSource _vs){
  	vs=_vs;
  }

  public void draw(Graphics2D g){
  	int tlx = vs.topLeftX();
  	int tly = vs.topLeftY();
  	int w = vs.width();
  	AffineTransform at = AffineTransform.getTranslateInstance(tlx,tly);
  	at.scale(w,w);
   	Path2D.Double shape=new Path2D.Double();
    if(vs.getDirection()==0.0){
         shape = (Path2D.Double) at.createTransformedShape(polyline_r);
         vs.setDirection(1.0);
    }
    else if(vs.getDirection()==1.0){
         shape = (Path2D.Double) at.createTransformedShape(polyline_u);
         vs.setDirection(2.0);
    }
    else if(vs.getDirection()==2.0){
         shape = (Path2D.Double) at.createTransformedShape(polyline_l);
         vs.setDirection(3.0);
    }
    else{
         shape = (Path2D.Double) at.createTransformedShape(polyline_d);
         vs.setDirection(0.0);
    }
    if(vs.getOverWrite())
  		g.setColor(Color.RED);
  	else if (vs.getSelected())
  		g.setColor(Color.BLUE);
  	else
    	g.setColor(Color.BLACK);
    g.draw(shape);

  }
}