///// WireView.java /////
/**
 * Class that implements the resistor view.
 * @author Jesus Márquez Barrera
 */

import java.awt.*;
import java.awt.geom.*;

import java.io.*;

public class WireView implements Serializable{

  private static final double points[]={0,26.0/51,1};
  private static final Path2D.Double polyline_h = new Path2D.Double(Path2D.WIND_EVEN_ODD,2);
  private static final Path2D.Double polyline_v = new Path2D.Double(Path2D.WIND_EVEN_ODD,2);
  private static final Path2D.Double polyline_c_r = new Path2D.Double(Path2D.WIND_EVEN_ODD,3);
  private static final Path2D.Double polyline_c_u = new Path2D.Double(Path2D.WIND_EVEN_ODD,3);
  private static final Path2D.Double polyline_c_l = new Path2D.Double(Path2D.WIND_EVEN_ODD,3);
  private static final Path2D.Double polyline_c_d = new Path2D.Double(Path2D.WIND_EVEN_ODD,3);
  private static final Path2D.Double polyline_t_r = new Path2D.Double(Path2D.WIND_EVEN_ODD,4);
  private static final Path2D.Double polyline_t_u = new Path2D.Double(Path2D.WIND_EVEN_ODD,4);
  private static final Path2D.Double polyline_t_l = new Path2D.Double(Path2D.WIND_EVEN_ODD,4);
  private static final Path2D.Double polyline_t_d = new Path2D.Double(Path2D.WIND_EVEN_ODD,4);
  private static final Path2D.Double polyline_q = new Path2D.Double(Path2D.WIND_EVEN_ODD,4);

  static {  // static initialization block. It creates a spring of length = 1.
  	//Horizontal Wire View
  	polyline_h.moveTo(points[0], points[1]);
    polyline_h.lineTo(points[2], points[1]);

  	//Vertical Wire View
  	polyline_v.moveTo(points[1], points[0]);
    polyline_v.lineTo(points[1], points[2]);

    //Up Elbow Wire View
    polyline_c_u.moveTo(points[1], points[0]);
    polyline_c_u.lineTo(points[1], points[1]);
    polyline_c_u.lineTo(points[0], points[1]);

    //Right Elbow Wire View
    polyline_c_r.moveTo(points[2], points[1]);
    polyline_c_r.lineTo(points[1], points[1]);
    polyline_c_r.lineTo(points[1], points[0]);

    //Down Elbow Wire View
    polyline_c_d.moveTo(points[1], points[2]);
    polyline_c_d.lineTo(points[1], points[1]);
    polyline_c_d.lineTo(points[2], points[1]);

    //Left Elbow Wire View
    polyline_c_l.moveTo(points[0], points[1]);
    polyline_c_l.lineTo(points[1], points[1]);
    polyline_c_l.lineTo(points[1], points[2]);

    //Up Tri Wire View
    polyline_t_u.moveTo(points[0], points[1]);
    polyline_t_u.lineTo(points[2], points[1]);
    polyline_t_u.moveTo(points[1], points[1]);
    polyline_t_u.lineTo(points[1], points[0]);

    //Right Tri Wire View
    polyline_t_r.moveTo(points[1], points[0]);
    polyline_t_r.lineTo(points[1], points[2]);
    polyline_t_r.moveTo(points[1], points[1]);
    polyline_t_r.lineTo(points[2], points[1]);

    //Down Tri Wire View
    polyline_t_d.moveTo(points[0], points[1]);
    polyline_t_d.lineTo(points[2], points[1]);
    polyline_t_d.moveTo(points[1], points[1]);
    polyline_t_d.lineTo(points[1], points[2]);

    //left Tri Wire View
    polyline_t_l.moveTo(points[1], points[0]);
    polyline_t_l.lineTo(points[1], points[2]);
    polyline_t_l.moveTo(points[1], points[1]);
    polyline_t_l.lineTo(points[0], points[1]);

    //Quad Wire View
    polyline_q.moveTo(points[0], points[1]);
    polyline_q.lineTo(points[2], points[1]);
    polyline_q.moveTo(points[1], points[2]);
    polyline_q.lineTo(points[1], points[0]);
  }

  private static int type;
  private Wire wi;
   
  public WireView(Wire _wi){
  	wi=_wi;
    type=0;
  }

  public void draw(Graphics2D g){
    int tlx = wi.topLeftX();
  	int tly = wi.topLeftY();
  	int w = wi.width();
  	AffineTransform at = AffineTransform.getTranslateInstance(tlx,tly);
  	at.scale(w,w);
    Path2D.Double shape =new Path2D.Double();

    switch(type){                       //para prueba
      case 0: 	if(wi.getDirection()==0.0){
		        	shape = (Path2D.Double) at.createTransformedShape(polyline_h);
		         	wi.setDirection(1.0);
		        }
		    	else{
		         	shape = (Path2D.Double) at.createTransformedShape(polyline_v);
		         	wi.setDirection(0.0);
		    	}
		    	break;   //para prueba

      case 1: 	if(wi.getDirection()==0.0){
			         shape = (Path2D.Double) at.createTransformedShape(polyline_c_r);
			         wi.setDirection(1.0);
			    }
			    else if(wi.getDirection()==1.0){
			         shape = (Path2D.Double) at.createTransformedShape(polyline_c_u);
			         wi.setDirection(2.0);
			    }
			    else if(wi.getDirection()==2.0){
			         shape = (Path2D.Double) at.createTransformedShape(polyline_c_l);
			         wi.setDirection(3.0);
			    }
			    else{
			         shape = (Path2D.Double) at.createTransformedShape(polyline_c_d);
			         wi.setDirection(0.0);
			    }
			    break;

      case 2: 	if(wi.getDirection()==0.0){
			         shape = (Path2D.Double) at.createTransformedShape(polyline_t_r);
			         wi.setDirection(1.0);
			    }
			    else if(wi.getDirection()==1.0){
			         shape = (Path2D.Double) at.createTransformedShape(polyline_t_u);
			         wi.setDirection(2.0);
			    }
			    else if(wi.getDirection()==2.0){
			         shape = (Path2D.Double) at.createTransformedShape(polyline_t_l);
			         wi.setDirection(3.0);
			    }
			    else{
			         shape = (Path2D.Double) at.createTransformedShape(polyline_c_d);
			         wi.setDirection(0.0);
			    }
			    break;


      case 3: 	shape = (Path2D.Double) at.createTransformedShape(polyline_q);
      			break;


      default : break;
    }

    if(type<3)
      type++;
    else
      type=0;
 	if(wi.getSelected())
  		if (wi.getOverWrite())
  			g.setColor(Color.RED);
  		else g.setColor(Color.BLUE);
  	else
    	g.setColor(Color.BLACK);
  	g.draw(shape);

 	}
}